package routers

import (
	"spaceofcheng/services/controllers/card"
	"spaceofcheng/services/controllers/coupon"
	"spaceofcheng/services/controllers/course"
	"spaceofcheng/services/controllers/customer"
	"spaceofcheng/services/controllers/goods"
	"spaceofcheng/services/controllers/gymcard"
	"spaceofcheng/services/controllers/user"

	"github.com/astaxie/beego"
)

func getWechatRoutes() beego.LinkNamespace {
	prefix := beego.AppConfig.String("api::wechat")

	return beego.NSNamespace(prefix,
		// 会员
		beego.NSRouter("/customer", &customer.CustomerController{}, "get:GetCustWXByID"),
		beego.NSRouter("/customer/user", &user.UserController{}, "get:GetUserCustomer"),
		beego.NSRouter("/customer/coupon", &coupon.CouponController{}, "get:GetCouponByCustomer"),
		beego.NSRouter("/customer/card", &card.CardController{}, "get:GetCardByCustomer"),

		// 下单
		beego.NSRouter("/order/goods", &goods.GoodsController{}, "post:PostOrder"),
		beego.NSRouter("/order/course", &course.CourseController{}, "post:PostOrder"),

		// 课程
		beego.NSRouter("/course/user", &course.CourseController{}, "get:GetCustomerCourse"),
		beego.NSRouter("/course/user/:id", &course.CourseController{}, "get:GetCustomerCourseByID"),

		// 商品订单
		beego.NSRouter("/goods/user", &goods.GoodsController{}, "get:GetCustomerOrders"),

		// 案场订单数量
		beego.NSRouter("/goods/case/:caseid", &goods.GoodsController{}, "get:GetCaseOrdersNum"),

		// 客户游泳健身卡
		beego.NSRouter("/gymcard", &gymcard.GymcardController{}, "get:GetGymcardListByCustomerId"),
		beego.NSRouter("/gymcard/:customerGymId", &gymcard.GymcardController{}, "get:GetCustomerGymDetailById"),
		beego.NSRouter("/gymcard/:gymcardId/:sysuserId", &gymcard.GymcardController{}, "post:SendGymToCustomer"),

		// 禁止人员
		beego.NSRouter("/user/forbid", &user.UserController{}, "get:GetForbidUsers"),
		beego.NSRouter("/user/forbid/:userid/:type", &user.UserController{}, "post:SaveForbidUser"),
		beego.NSRouter("/user/forbid/:userid/:type", &user.UserController{}, "put:OpenForbidUser"),

		// 用户
		beego.NSRouter("/user/:type", &user.UserController{}, "get:GetCaseUserByType"),
		beego.NSRouter("/user/detail/:id", &user.UserController{}, "get:GetCaseUserByID"),

		// 优惠券
		beego.NSRouter("/coupon/:id", &coupon.CouponController{}, "get:GetCouponByID"),
		beego.NSRouter("/coupon/detail/:id", &coupon.CouponController{}, "get:GetCouponWithCustomer"),

		// 卡
		beego.NSRouter("/card/:id", &card.CardController{}, "get:GetCardByID"),
		beego.NSRouter("/card/detail/:id", &card.CardController{}, "get:GetCardWithCustomer"),
	)
}
