package cases

import (
	"spaceofcheng/services/models/cases"
	"spaceofcheng/services/models/marketing"
	"spaceofcheng/services/utils"
	"spaceofcheng/services/models/model"
	"github.com/astaxie/beego"
	"encoding/json"
)

// SigninServ 系统处理
type SigninServ struct {
	ctx *utils.Context
	dao *cases.SigninDAO
	marDao  *marketing.MarketingDAO
	caseDao     *cases.CaseDAO
}

// NewSigninServ 初始化
func NewSigninServ(ctx *utils.Context) *SigninServ {
	return &SigninServ{
		ctx: ctx,
		dao: cases.NewSigninDAO(ctx),
		marDao: marketing.NewMarketingDAO(ctx),
		caseDao: cases.NewCaseDAO(ctx),
	}
}

//GetSigninWhere
/**
GetSigninWhere 根据条件查询签到记录
		 条件:
				 selectType: 今天,本周,本月,今年,全部
				 caseid: 案场ID
*/
func (s *SigninServ) GetSigninWhere(selectType int, caseids string, page, pageSize int) (map[string]interface{}, error) {

	info, err := s.dao.GetSigninWhere(selectType, caseids, page, pageSize)
	var total int
	if err != nil {
		beego.Error(err)
		return nil, err
	}
	if len(info) > 0 {
		total = len(info)
	}

	return map[string]interface{}{
		"list":     info,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, err
}

// 添加 签到记录
func (s *SigninServ) AddSignin(signin model.TaCheckinRecord,caseId string,activityId string,userMap *model.TaUserMapping) (*model.TaCheckinRecord,error) {
	if signin.OpenId == "" {
		return nil, utils.LogError("没有OpenId")
	}
	if signin.Phone == "" {
		return nil, utils.LogError("没有Phone手机号")
	}
	if caseId == "" {
		return nil,utils.LogError("没有案场ID")
	}
	if activityId == ""  {
		return nil,utils.LogError("没有活动ID")
	}

	// 获取上下文的用户
	user := s.ctx.Get("user").(model.SysUser)
	casesInfo,err := s.caseDao.GetCaseByID(caseId)
	activityInfo,err := s.marDao.GetMarketingById(activityId)
	
	// 定义Map
	var jsonMap = map[string]string{}
	accountInfo := userMap.AccountInfo
	// 转换JSON
	var jsonBlob = []byte(accountInfo)
	jsonErr := json.Unmarshal(jsonBlob, &jsonMap)

	if jsonErr != nil {
		return nil,utils.LogError("accountInfo转换json失败")
	}
	// openId
	signin.OpenId = jsonMap["openid"]
	// 微信昵称
	signin.CustomerName = jsonMap["nickname"]
	// 客户姓名
	signin.Name = user.UserName
	// 客户ID
	signin.CustomerId = user.UserId

	// 案场
	signin.CaseId = casesInfo.CaseId
	signin.CaseName = casesInfo.CaseName

	// 活动
	signin.ActivityId = activityInfo.ActivityId
	signin.ActivityName = activityInfo.ActivityName

	info, err := s.dao.AddSignin(signin)
	if err != nil {
		return nil,err
	}

	return &info,err
}
