package utils

import (
	"github.com/zjxpcyc/wechat/wx"
)

var wxClients map[string]*wx.Client

type WechatUser struct {
	OpenID     string  `json:"openid"`
	NickName   string  `json:"nickname"`
	Sex        float64 `json:"sex"`
	Province   string  `json:"province"`
	City       string  `json:"city"`
	Country    string  `json:"country"`
	HeadImgURL string  `json:"headimgurl"`
	UnionID    string  `json:"unionid"`
}

// WxClientSingleton 初始化
func WxClientSingleton(org string, cert map[string]string) {
	if wxClients == nil {
		wxClients = map[string]*wx.Client{
			org: wx.NewClient(cert),
		}
	} else {
		if _, ok := wxClients[org]; !ok {
			wxClients[org] = wx.NewClient(cert)
		}
	}
}

// WxClientFor 微信客户端
func WxClientFor(org string) *wx.Client {
	return wxClients[org]
}

// GetWxAppID 获取微信ID
func GetWxAppID(org string) string {
	return wxClients[org].GetAppID()
}

func init() {
	wx.SetLogInst(defaultLogger)
}

// MapToWechatUser 映射微信人员
func MapToWechatUser(data map[string]interface{}) *WechatUser {
	subscribe, has := data["subscribe"]
	if has {
		if subscribe == nil {
			return nil
		}

		sub := subscribe.(float64)
		if sub == 0 {
			return nil
		}
	}

	user := WechatUser{
		OpenID: data["openid"].(string),
	}

	if data["sex"] != nil {
		user.Sex = data["sex"].(float64)
	}

	if data["province"] != nil {
		user.Province = data["province"].(string)
	}

	if data["city"] != nil {
		user.City = data["city"].(string)
	}

	if data["country"] != nil {
		user.Country = data["country"].(string)
	}

	if data["headimgurl"] != nil {
		user.HeadImgURL = data["headimgurl"].(string)
	}

	if data["unionid"] != nil {
		user.UnionID = data["unionid"].(string)
	}

	return &user
}
